@@ -1,18 +1,11 @@
 import typer
 import requests
 from tinydb import TinyDB, Query
-from neoclima.commands_svc import get_emoji
-from dotenv import load_dotenv
-import os
 
 app = typer.Typer()
 
 db = TinyDB("./db.json")
 
-load_dotenv()
-
-api_key = os.getenv("API_KEY")
-
 @app.command()
 def now(city_nickname: str):
     """
@@ -22,12 +15,9 @@ def now(city_nickname: str):
     if city:
         lat = city[0]["coordinates"][0]
         lon = city[0]["coordinates"][1]
-        r = requests.get(f"https://api.openweathermap.org/data/2.5/weather?lat={lat}&units=metric&lon={lon}&limit=1&appid={api_key}")
-        content = r.json()
-        current_temperature = int(content["main"]["temp"])
-        weather = content["weather"][0]["main"]
-        emoji = get_emoji(weather)
-        print(emoji + "  " + str(current_temperature) + "°C")
+        r = requests.get(f"https://api.open-meteo.com/v1/forecast?latitude={lat}&longitude={lon}&current_weather=True")
+        current_temperature = int(r.json()["current_weather"]["temperature"])
+        print(str(current_temperature) + "°C")
     else:
         print("City not added!")
 
@@ -40,11 +30,10 @@ def add(city_nickname: str):
     city_nickname_exists = bool(db.search(Query().city == city_nickname))
     if not city_nickname_exists:
         country = input("Type the country name or code (ISO3166): ")
-        state = input("Type the state code (only for US): ")
         city = input("Type the city name: ")
-        r = requests.get(f"http://api.openweathermap.org/geo/1.0/direct?q={city},{state},{country}&limit=1&appid={api_key}")
-        lat = r.json()[0]["lat"]
-        lon = r.json()[0]["lon"]
+        r = requests.get(f"https://geocoding-api.open-meteo.com/v1/search?country_code={country}&name={city}&count=1")
+        lat = r.json()["results"][0]["latitude"]
+        lon = r.json()["results"][0]["longitude"]
         db.insert({"city": city_nickname, "coordinates": [lat,lon]})
         print("City added succesfully!")
     else:
